@@ -1,19 +1,29 @@
 <?php
 /**
- * Abstract implementation of the Horde_Data:: API for IMC data -
- * vCards and iCalendar data, etc. Provides a number of utility
- * methods that vCard and iCalendar implementation can share and rely
- * on.
- *
- * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @author   Jan Schneider <jan@horde.org>
  * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL
  * @package  Data
  */
+
+/**
+ * Abstract implementation of the Horde_Data:: API for IMC data - vCards and
+ * iCalendar data, etc.
+ *
+ * Provides a number of utility methods that vCard and iCalendar implementation
+ * can share and rely on.
+ *
+ * @author    Jan Schneider <jan@horde.org>
+ * @category  Horde
+ * @copyright 1999-2017 Horde LLC
+ * @license   http://www.horde.org/licenses/lgpl21 LGPL
+ * @package   Data
+ */
 class Horde_Data_Imc extends Horde_Data_Base
 {
     /**
@@ -93,13 +103,11 @@ class Horde_Data_Imc extends Horde_Data_Base
         switch ($action) {
         case Horde_Data::IMPORT_FILE:
             parent::nextStep($action, $param);
-            $this->importFile($_FILES['import_file']['tmp_name']);
-            return $this->_iCal->getComponents();
+            return $this->importFile($_FILES['import_file']['tmp_name']);
 
         case Horde_Data::IMPORT_URL:
             parent::nextStep($action, $param);
-            $this->importUrl($this->_vars->import_url);
-            return $this->_iCal->getComponents();
+            return $this->importUrl($this->_vars->import_url);
         }
 
         return parent::nextStep($action, $param);
